@@ -1,16 +1,16 @@
 package SHARYANTO::Hash::Util;
 
+our $DATE = '2014-10-11'; # DATE
+our $VERSION = '0.76'; # VERSION
+
 use 5.010;
 use strict;
 use warnings;
-use Data::Clone;
 
 require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(rename_key);
 
-our $VERSION = '0.75'; # VERSION
-
 sub rename_key {
     my ($h, $okey, $nkey) = @_;
     die unless    exists $h->{$okey};
@@ -33,7 +33,7 @@ SHARYANTO::Hash::Util - Hash utilities
 
 =head1 VERSION
 
-This document describes version 0.75 of SHARYANTO::Hash::Util (from Perl distribution SHARYANTO-Utils), released on 2014-06-26.
+This document describes version 0.76 of SHARYANTO::Hash::Util (from Perl distribution SHARYANTO-Utils), released on 2014-10-11.
 
 =head1 SYNOPSIS
 
@@ -74,11 +74,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
