@@ -9,8 +9,8 @@ no warnings 'once';
 use Time::HiRes;
 use Time::Stopwatch;
 
-our $VERSION = '0.75'; # VERSION
-our $DATE = '2014-06-26'; # DATE
+our $VERSION = '0.76'; # VERSION
+our $DATE = '2014-10-11'; # DATE
 
 tie our($TIMER), 'Time::Stopwatch';
 
@@ -46,7 +46,7 @@ SHARYANTO::Timer::Simple - Simple timer
 
 =head1 VERSION
 
-This document describes version 0.75 of SHARYANTO::Timer::Simple (from Perl distribution SHARYANTO-Utils), released on 2014-06-26.
+This document describes version 0.76 of SHARYANTO::Timer::Simple (from Perl distribution SHARYANTO-Utils), released on 2014-10-11.
 
 =head1 SYNOPSIS
 
@@ -95,11 +95,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
